@@ -1,6 +1,6 @@
 #
 # (c) Jan Gehring <jan.gehring@gmail.com>
-# 
+#
 # vim: set ts=3 sw=3 tw=0:
 # vim: set expandtab:
 #
@@ -23,46 +23,40 @@ Query the Hoststatus of an OpenNebula host.
     user     => "oneadmin",
     password => "onepass",
  );
-    
+
  my ($host) = grep { $_->name eq "one-sandbox" } $one->get_hosts();
  for my $vm ($host->vms) { ... }
 
 =cut
 
 package Net::OpenNebula::Host;
-$Net::OpenNebula::Host::VERSION = '0.306.0';
+$Net::OpenNebula::Host::VERSION = '0.307.0';
 use Net::OpenNebula::RPC;
 push our @ISA , qw(Net::OpenNebula::RPC);
 
 use constant ONERPC => 'host';
+use constant NAME_FROM_TEMPLATE => 1;
 
 # From include/Host.h
 use constant STATES => qw(INIT MONITORING_MONITORED MONITORED ERROR DISABLED MONITORING_ERROR MONITORING_INIT MONITORING_DISABLED);
 
-sub name {
-   my ($self) = @_;
-   my $name = $self->_get_info_extended('NAME');
-
-   return $name->[0];
-}
-
 sub vms {
-   my ($self) = @_;
-   my $vms = $self->_get_info_extended('VMS');
-   my @ret;
-   for my $vm_id (@{ $vms->[0]->{ID} }) {
-      push @ret, $self->{rpc}->get_vm($vm_id);
-   }
+    my ($self) = @_;
+    my $vms = $self->_get_info_extended('VMS');
+    my @ret;
+    foreach my $vm_id (@{ $vms->[0]->{ID} }) {
+        push @ret, $self->{rpc}->get_vm($vm_id);
+    }
 
-   return @ret;
+    return @ret;
 }
 
 sub used {
-   my ($self) = @_;
-   my $hs = $self->_get_info_extended('HOST_SHARE');
-   if (defined($hs->[0]->{RUNNING_VMS}->[0])) {
-       return 1;
-   } 
+    my ($self) = @_;
+    my $hs = $self->_get_info_extended('HOST_SHARE');
+    if (defined($hs->[0]->{RUNNING_VMS}->[0])) {
+        return 1;
+    }
 };
 
 
@@ -98,7 +92,7 @@ sub state {
    if(!defined($state)) {
        $self->warn('Undefined '.ONERPC.'-state for id ', $self->id);
        return;
-   } 
+   }
 
    return (STATES)[$state];
 };
