@@ -2,11 +2,12 @@ use strict;
 use warnings;
 
 package Net::OpenNebula::RPC;
-$Net::OpenNebula::RPC::VERSION = '0.306.0';
+$Net::OpenNebula::RPC::VERSION = '0.307.0';
 use Data::Dumper;
 
 use constant ONERPC => 'rpc';
 use constant ONEPOOLKEY => undef;
+use constant NAME_FROM_TEMPLATE => 0;
 
 
 # If cacche->{add} attibute is true, add the cache for the following method
@@ -72,6 +73,7 @@ sub _onerpc_simple {
 # opts
 #   clearcache: if set to 1, clears the cache and queries again
 #   id: get info for other id (if missing, use $self->id)
+# Return extended_data (and if not existing, rerieves and sets extended_data)
 sub _get_info {
     my ($self, %option) = @_;
 
@@ -86,6 +88,8 @@ sub _get_info {
     if(! exists $self->{extended_data} || (exists $option{clearcache} && $option{clearcache} == 1)) {
         $self->{extended_data} = $self->_onerpc("info", [ int => $id ]);
     }
+
+    return $self->{extended_data};
 }
 
 # Similar to _get_info, but will try with with clearcache if C<entry> can't be
@@ -107,6 +111,30 @@ sub _get_info_extended {
     }
 }
 
+
+sub name {
+    my ($self) = @_;
+
+    my $name;
+
+    if (NAME_FROM_TEMPLATE) {
+        my $ext_name = $self->_get_info_extended('NAME');
+
+        $name = $ext_name->[0];
+    }
+
+    if (!defined($name)) {
+        $name = $self->{data}->{NAME}->[0];
+        if (! $name) {
+            my $template = $self->_get_info_extended('TEMPLATE');
+            # if vm NAME is set, use that instead of template NAME
+            $name = $template->[0]->{NAME}->[0];
+        }
+    }
+
+    return $name;
+}
+
 sub id {
    my ($self) = @_;
    return $self->{data}->{ID}->[0];
@@ -182,14 +210,6 @@ sub update {
                           );
 }
 
-# Chown
-# options
-#    uid : uid to use
-#    gid : gid to use
-#    one : Net::OpenNebula instance to use for user/groupname lookup
-#          (i.e. when uid/gid is not a integer)
-#          It wil use $one->get_users and/or $one->get_groups methods.
-
 sub _lookup
 {
     my ($self, $type, $id, $one) = @_;
@@ -226,6 +246,14 @@ sub _lookup
 }
 
 
+# Chown
+# options
+#    uid : uid to use
+#    gid : gid to use
+#    one : Net::OpenNebula instance to use for user/groupname lookup
+#          (i.e. when uid/gid is not a integer)
+#          It wil use $one->get_users and/or $one->get_groups methods.
+
 sub chown
 {
     my ($self, %opts) = @_;
@@ -288,8 +316,10 @@ sub _get_instances {
 
     my $reply = $self->{rpc}->_rpc("one.$pool.info", @args);
 
-    for my $data (@{ $reply->{$key} }) {
-        my $inst = $self->new(rpc => $self->{rpc}, data => $data);
+    foreach my $data (@{ $reply->{$key} }) {
+        # This is data from pool.info, so it is as complete as individual info
+        # so we can set it as extended_data
+        my $inst = $self->new(rpc => $self->{rpc}, data => $data, extended_data => $data);
         if (! defined($nameregex) || ($inst->name && $inst->name =~ $nameregex) ) {
             push(@ret, $inst);
         }
