@@ -8,20 +8,12 @@ use strict;
 use warnings;
 
 package Net::OpenNebula::User;
-$Net::OpenNebula::User::VERSION = '0.306.0';
+$Net::OpenNebula::User::VERSION = '0.307.0';
 use Net::OpenNebula::RPC;
 push our @ISA , qw(Net::OpenNebula::RPC);
 
 use constant ONERPC => 'user';
 
-sub name {
-   my ($self) = @_;
-   $self->_get_info();
-
-   # if user NAME is set, use that instead of template NAME
-   return $self->{data}->{NAME}->[0] || $self->{data}->{TEMPLATE}->[0]->{NAME}->[0];
-}
-
 sub create {
    my ($self, $name, $password, $driver) = @_;
    if (! defined $driver) {
