@@ -9,7 +9,7 @@ use strict;
 use warnings;
 
 package Net::OpenNebula::VM;
-$Net::OpenNebula::VM::VERSION = '0.306.0';
+$Net::OpenNebula::VM::VERSION = '0.307.0';
 use Net::OpenNebula::RPC;
 push our @ISA , qw(Net::OpenNebula::RPC);
 
@@ -27,14 +27,6 @@ use constant {
 
 use Net::OpenNebula::VM::NIC;
 
-sub name {
-   my ($self) = @_;
-   my $template = $self->_get_info_extended('TEMPLATE');
-   
-   # if vm NAME is set, use that instead of template NAME
-   return $self->{data}->{NAME}->[0] || $template->[0]->{NAME}->[0];
-}
-
 sub nics {
    my ($self) = @_;
    my $template = $self->_get_info_extended('TEMPLATE');
